OC.L10N.register(
    "circles",
    {
    "Circles" : "Cercles",
    "Circles' files" : "Fichiers des cercles",
    "Select circles to filter by" : "Sélectionner les cercles à filtrer",
    "No circles found" : "Aucun cercle trouvé",
    "Please select circles to filter by" : "Veuillez sélectionner les cercles à filtrer",
    "No files found for the selected circles" : "Aucun fichier pour les cercles sélectionnés",
    "You created the circle {circle}" : "Vous avez créé le cercle {circle}",
    "{author} created the circle {circle}" : "{author} a créé le cercle {circle}",
    "You deleted {circle}" : "Vous avez supprimé {circle}",
    "{author} deleted {circle}" : "{author} a supprimé {circle}",
    "You linked {group} to {circle}" : "Vous avez lié {group} à {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} a été lié à {circle} par {author}",
    "You unlinked {group} from {circle}" : "Vous avez délié {group} de {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} a été délié de {circle} par {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Vous avez changé le niveau du groupe lié {group} dans {circle} à %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} a changé le niveau du groupe lié {group} dans {circle} à %1$s",
    "You sent a request to link {circle} with {remote}" : "Vous avez envoyé une requête pour lier {circle} avec {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} a envoyé une requête pour lier {circle} avec {remote}",
    "{remote} requested a link with {circle}" : "{remote} a demandé un lien avec {circle}",
    "The request to link {circle} with {remote} has been rejected" : "La demande de lier {circle} avec {remote} a été rejetée",
    "The request to link {remote} with {circle} has been canceled remotely" : "La demande de lier {remote} avec {circle} a été annulée à distance",
    "The request to link {circle} with {remote} has been accepted" : "La demande de lier {circle} avec {remote} a été acceptée",
    "You dismissed the request to link {remote} with {circle}" : "Vous avez ignoré la demande de lier {remote} avec {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} a ignoré la demande de lier {remote} avec {circle}",
    "You canceled the request to link {circle} with {remote}" : "Vous avez annulé la demande de lier {circle} avec {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} a annulé la demande de lier {circle} avec {remote}",
    "You accepted the request to link {remote} with {circle}" : "Vous avez accepté la demande de lier {remote} avec {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} a accepté la demande de lier {remote} avec {circle}",
    "A link between {circle} and {remote} is now up and running" : "Un lien entre {circle} et {remote} est maintenant opérationnel",
    "The link between {circle} and {remote} has been shutdown remotely" : "Le lien entre {circle} et {remote} a été fermé à distance",
    "You closed the link between {circle} and {remote}" : "Vous avez fermé le lien entre {circle} et {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} a fermé le lien entre {circle} et {remote}",
    "You joined {circle}" : "Vous avez rejoint {circle}",
    "{member} joined {circle}" : "{member} a rejoint {circle}",
    "You accepted the invitation to join {circle}" : "Vous avez accepté l'invitation pour rejoindre {circle}",
    "{member} accepted the invitation to join {circle}" : "[member] a accepté l'invitation pour rejoindre [circle}",
    "You added {member} as member to {circle}" : "Vous avez ajouté {member} comme membre de {circle}",
    "You have been added as member to {circle} by {author}" : "Vous avez été ajouté comme membre de {circle} par {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} a été ajouté comme membre de {circle} par {author}",
    "You added {external} to {circle}" : "Vous avez ajouté {external} à {circle}",
    "{external} has been added to {circle} by {author}" : "{external} a été ajouté à {circle} par {author}",
    "You accepted {member}'s request to join {circle}" : "Vous avez accepté la demande de {member} pour rejoindre {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Votre demande pour rejoindre {circle} a été acceptée par {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La demande de {member} pour rejoindre {circle} a été acceptée par {author}",
    "You left {circle}" : "Vous quittez {circle}",
    "{member} left {circle}" : "{member} a quitté {circle}",
    "You declined the invitation to join {circle}" : "Vous avez refusé l'invitation à rejoindre {circle}",
    "{member} declined an invitation to join {circle}" : "{member} a refusé l'invitation à rejoindre {circle}",
    "You cancelled your request to join {circle}" : "Vous avez annulé la demande pour rejoindre {circle}",
    "{member} cancelled his request to join {circle}" : "{member} a annulé sa demande pour rejoindre {circle}",
    "You removed {member} from {circle}" : "Vous avez supprimé {member} de {circle}",
    "You have been removed from {circle} by {author}" : "Vous avez été retiré de {circle} par {author}",
    "{member} has been removed from {circle} by {author}" : "{member} a été retiré de {circle} par {author}",
    "You removed {external} from {circle}" : "Vous avez retiré {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} a été retiré de {circle} par {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Vous avez annulé l'invitation de {member} à rejoindre {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Votre invitation à rejoindre {circle} a été annulé par {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} a annulé l'invitation de {member} à rejoindre {circle}",
    "You dismissed {member}'s request to join {circle}" : "Vous avez rejeté la demande de {member} pour rejoindre {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Votre demande pour rejoindre {circle} a été rejetée par {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La demande de {member} de rejoindre {circle} a été rejetée par {author}",
    "You invited {member} to join {circle}" : "Vous avez invité {member} à rejoindre {circle}",
    "You have been invited to join {circle} by {author}" : "Vous avez été invité à rejoindre {circle} par {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} a été invité à rejoindre {circle} par {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Vous avez changé le niveau de {member} dans {circle} à %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} a changé votre niveau dans {circle} à %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} a changé le niveau de {member} dans {circle} à %1$s",
    "You sent a request to join {circle}" : "Vous avez envoyé une demande pour rejoindre {circle}",
    "{member} sent a request to join {circle}" : "{member} a envoyé une demande pour rejoindre {circle}",
    "You are the new owner of {circle}" : "Vous êtes le nouveau propriétaire de {circle}",
    "{member} is the new owner of {circle}" : "{member} est le nouveau propriétaire de {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Sur les événements survenant dans un <strong>Cercle</strong> dont vous êtes membre",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Tous les événements importants dans un <strong>Cercle</strong> que vous modérez",
    "On global events happening in any <strong>Circle</strong>" : "Sur les événements globaux survenant dans n’importe quel <strong>Cercle</strong>",
    "Single" : "Simple",
    "Personal" : "Personnel",
    "System" : "Système",
    "Visible" : "Visible",
    "Open" : "Ouvert",
    "Invite" : "Inviter",
    "Join Request" : "Joindre la requête",
    "Friends" : "Amis",
    "Password Protected" : "Protégé par mot de passe",
    "No Owner" : "Pas de propriétaire",
    "Hidden" : "Caché",
    "Backend" : "Infrastructure",
    "Local" : "Local",
    "Root" : "Racine",
    "Circle Invite" : "Inviter dans un cercle",
    "Federated" : "Fédéré",
    "Mount point" : "Point de montage",
    "Nextcloud Account" : "Compte Nextcloud",
    "Nextcloud Group" : "Groupe Nextcloud",
    "Email Address" : "Adresse e-mail",
    "Contact" : "Contact",
    "Circle" : "Cercle",
    "Nextcloud App" : "App Nextcloud",
    "Member" : "Membre",
    "Moderator" : "Modérateur",
    "Admin" : "Administrateur",
    "Owner" : "Propriétaire",
    "%s shared »%s« with you." : "%s a partagé «%s» avec vous.",
    "%s shared »%s« with \"%s\"." : "%s a partagé »%s« avec \"%s\".",
    "%s on %s" : "%s sur %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partagé »%2$s« avec vous.\nVous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s a partagé »%2$s« avec vous. Vous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.",
    "Password to access »%1$s« shared to you by %2$s" : "Mot de passe pour accéder à «%1$s» partagé avec vous par %2$s",
    "Password to access »%s«" : "Mot de passe pour accéder à «%s»",
    "It is protected with the following password:" : "Protégé par le mot de passe suivant :",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir.",
    "Open »%s«" : "Ouvrir «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s a partagé plusieurs fichiers avec vous.\nVous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$sa partagé plusieurs fichiers avec vous. Vous devriez déjà avoir reçu un courrier avec un lien pour y accéder.",
    "Password to access files shared to you by %1$s" : "Mot de passe pour accéder aux fichiers partagés avec vous par %1$s",
    "Password to access files" : "Mot de passe pour accéder aux fichiers",
    "%s shared multiple files with \"%s\"." : "%s a partagé plusieurs fichiers avec \"%s\".",
    "%s shared multiple files with you." : "%s a partagé plusieurs fichiers avec vous.",
    "Boot up" : "Démarrage",
    "Nextcloud Initialization" : "Initialisation de Nexctcloud",
    "Circles App Initialization" : "Initialisation de l'application Cercles",
    "Fresh installation status" : "Statut de l'installation",
    "Building Local Database" : "Construction de la base de données locale",
    "Testing Basic Circle Creation" : "Test de création d'un cercle basique",
    "Adding local users and moderators" : "Ajout d'utilisateurs locaux et de modérateurs",
    "Circle not found" : "Cercle non trouvé",
    "Circle not found " : "Cercle non trouvé",
    "This member does not exist" : "Ce membre n'existe pas",
    "This account is already a member of the circle" : "Ce compte est déjà membre du cercle",
    "Federated link not found" : "Lien fédéré non trouvé",
    "This feature is not available for personal circles" : "Cette fonctionnalité n'est pas disponible pour les cercles personnels",
    "The circle is not federated" : "Le cercle n'est pas fédéré",
    "You cannot join this circle" : "Vous ne pouvez pas rejoindre ce cercle",
    "This member is not a moderator" : "Ce membre n'est pas modérateur",
    "Insufficient privileges" : "Privilèges insuffisants",
    "This member is the owner of the circle" : "Ce membre est propriétaire du cercle",
    "Level cannot be changed for this type of member" : "Le niveau ne peut pas être modifié pour ce type de membre",
    "You are already a member of this circle" : "Vous êtes déjà membre du cercle",
    "You have been blocked from this circle" : "Vous avez été bloqué de ce cercle",
    "The account is already a member of this circle" : "Le compte est déjà membre de ce cercle",
    "The account has already been invited into this circle" : "Le compte a déjà été invité à participer à ce cercle",
    "%s (Circle owned by %s)" : "%s (Cercle appartenant à %s)",
    "You are now a member of the Circle \"%2$s\"" : "Vous êtes maintenant membre du cercle \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Vous avez été invité par %1$s dans le cercle \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s a demandé à être membre du cercle \"%2$s\"",
    "Accept" : "Accepter",
    "Refuse" : "Refuser",
    "Leave the circle" : "Quitter le cercle",
    "%s" : "%s",
    "Personal Circle" : "Cercle personnel",
    "%s owned by %s" : "%s appartenant à %s",
    "You need a specify a type of circle" : "Vous devez spécifier un type de cercle",
    "A circle with that name exists" : "Ce nom de cercle existe",
    "This member is not the owner of the circle" : "Ce membre n'est pas propriétaire du cercle",
    "This member is not an admin of the circle" : "Ce membre n'est pas un administrateur du cercle",
    "Group contains too many members" : "Le groupe contient trop de membres",
    "This group does not exist" : "Ce groupe n'existe pas",
    "This group is already linked to the circle" : "Ce groupe es déjà lié au cercle",
    "You cannot edit level in a personal circle" : "Vous ne pouvez pas modifier dans ce cercle personnel",
    "Group cannot be set as owner of a circle" : "Le groupe ne peut pas être défini comme propriétaire d'un cercle",
    "now" : "A l'instant",
    "This account does not exist" : "Ce compte n'existe pas",
    "Email format is not valid" : "Le format d'e-mail est invalide",
    "This contact is not available" : "Ce contact n'est pas disponible",
    "You have no permission to create a new circle" : "Vous n'avez pas l'autorisation de créer un nouveau cercle",
    "%s shared a file with \"%s\"." : "%s a partagé un fichier avec \"%s\".",
    "%s shared a file with you." : "%sa partagé un fichier avec vous.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partagé quelque chose avec vous\nVous devriez avoir déjà reçu un e-mail séparé avec un lien pour y accéder\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$sa partagé quelque chose avec vous\nVous devriez avoir déjà reçu un e-mail séparé avec un lien pour y accéder",
    "Password to access content shared with you by %1$s" : "Mot de passe pour accéder au contenu partagé avec vous par %1$s",
    "Password to access content" : "Mot de passe pour accéder au contenu",
    "This item is already shared with this circle" : "Cet item est déjà partagé avec ce cercle",
    "Bring cloud-users closer together." : "Permet de rapprocher les utilisateur du cloud ensemble ",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "L'application \"Cercles\" permet aux utilisateurs de créer leurs propres groupes de personnes/collègues/amis\nCes groupes de gens (ou \"cercles\" peuvent alors être utilisés par toutes les autres applications à des fins de partage.",
    "No files in here" : "Aucun fichier",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "Nextcloud User" : "Utilisateur Nextcloud",
    "Initialisation Nextcloud" : "Initialisation de Nextcloud",
    "Initialisation Circles App" : "Initialisation de l'application Cercles",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Vous ne pouvez pas utiliser l'application Cercles à moins que votre administrateur ait autorisé au moins un type de cercles",
    "This user is already a member of the circle" : "Cet utilisateur est déjà membre du cercle",
    "The user is already a member of this circle" : "L'utilisateur est déjà membre de ce cercle",
    "The user has already been invited into this circle" : "L'utilisateur a déjà été invité dans ce cercle",
    "This user does not exist" : "Cet utilisateur n'existe pas",
    "Could not find share" : "Impossible de trouver le partage",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "L'applications Cercles permet aux utilisateurs de créer leurs propres groupes d'utilisateurs/collègues/amis.\nCes groupes d'utilisateurs (ou \"cercles\") peuvent alors être utilisés par toutes les autres applications pour partager des éléments."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
